@@ -209,6 +209,24 @@ typedef	byte	fseg_inode_t;
 
 static constexpr byte FSEG_MAGIC_N_BYTES[4]={0x05,0xd6,0x69,0xd2};
 
+#define	FSEG_FILLFACTOR		8	/* If the number of unused but reserved
+					pages in a segment is less than
+					reserved pages / FSEG_FILLFACTOR,
+					and there are
+					at least FSEG_FRAG_LIMIT used pages,
+					then we allow a new empty extent to
+					be added to the segment in
+					fseg_alloc_free_page_general().
+					Otherwise, we
+					use unused pages of the segment. */
+
+#define FSEG_FRAG_LIMIT		FSEG_FRAG_ARR_N_SLOTS
+					/* If the segment has >= this many
+					used pages, it may be expanded by
+					allocating extents to the segment;
+					until that only individual fragment
+					pages are allocated from the space */
+
 #define	FSEG_FREE_LIST_LIMIT	40	/* If the reserved size of a segment
 					is at least this many extents, we
 					allow extents to be put to the free
@@ -276,7 +294,7 @@ Determine if a page is marked free.
 @param[in]	descr	extent descriptor
 @param[in]	offset	page offset within extent
 @return whether the page is free */
-inline bool xdes_is_free(const xdes_t *descr, uint32_t offset)
+inline bool xdes_is_free(const xdes_t *descr, ulint offset)
 {
   ut_ad(offset < FSP_EXTENT_SIZE);
   ulint index= XDES_FREE_BIT + XDES_BITS_PER_PAGE * offset;
@@ -460,36 +478,42 @@ fseg_free_page(
 dberr_t fseg_page_is_allocated(fil_space_t *space, unsigned page)
   MY_ATTRIBUTE((nonnull, warn_unused_result));
 
-MY_ATTRIBUTE((nonnull, warn_unused_result))
 /** Frees part of a segment. This function can be used to free
 a segment by repeatedly calling this function in different
 mini-transactions. Doing the freeing in a single mini-transaction
 might result in too big a mini-transaction.
-@param block   segment header block
-@param header  segment header offset in the block;
-NOTE: if the header resides on first page of the frag list of the segment,
-this pointer becomes obsolete after the last freeing step
-@param mtr     mini-transaction
+@param	header	segment header; NOTE: if the header resides on first
+		page of the frag list of the segment, this pointer
+		becomes obsolete after the last freeing step
+@param	mtr	mini-transaction
+@param	ahi	Drop the adaptive hash index
 @return whether the freeing was completed */
-bool fseg_free_step(buf_block_t *block, size_t header, mtr_t *mtr
+bool
+fseg_free_step(
+	fseg_header_t*	header,
+	mtr_t*		mtr
 #ifdef BTR_CUR_HASH_ADAPT
-                    , bool ahi=false /*!< whether to drop the AHI */
+	,bool		ahi=false
 #endif /* BTR_CUR_HASH_ADAPT */
-                    ) noexcept;
+	)
+	MY_ATTRIBUTE((warn_unused_result));
 
-MY_ATTRIBUTE((nonnull, warn_unused_result))
 /** Frees part of a segment. Differs from fseg_free_step because
 this function leaves the header page unfreed.
-@param block   segment header block; must reside on the first
-fragment page of the segment
-@param header  segment header offset in the block
-@param mtr     mini-transaction
+@param	header	segment header which must reside on the first
+		fragment page of the segment
+@param	mtr	mini-transaction
+@param	ahi	drop the adaptive hash index
 @return whether the freeing was completed, except for the header page */
-bool fseg_free_step_not_header(buf_block_t *block, size_t header, mtr_t *mtr
+bool
+fseg_free_step_not_header(
+	fseg_header_t*	header,
+	mtr_t*		mtr
 #ifdef BTR_CUR_HASH_ADAPT
-                               , bool ahi=false /*!< whether to drop the AHI */
+	,bool		ahi=false
 #endif /* BTR_CUR_HASH_ADAPT */
-                               ) noexcept;
+	)
+	MY_ATTRIBUTE((warn_unused_result));
 
 /** Reset the page type.
 Data files created before MySQL 5.1.48 may contain garbage in FIL_PAGE_TYPE.
@@ -549,6 +573,12 @@ inline void fsp_init_file_page(
 	mtr->init(block);
 }
 
+/** Truncate the system tablespace */
+void fsp_system_tablespace_truncate();
+
+/** Truncate the temporary tablespace */
+void fsp_shrink_temp_space();
+
 #ifndef UNIV_DEBUG
 # define fsp_init_file_page(space, block, mtr) fsp_init_file_page(block, mtr)
 #endif
